@@ -15,7 +15,7 @@ __END__
 
 =head1 NAME
 
-DBIx::SQLEngine::Criteria::Greater - Basic Comparison Criteria
+DBIx::SQLEngine::Criteria::Greater - Criteria for Basic Comparison
 
 =head1 SYNOPSIS
 
@@ -26,6 +26,14 @@ DBIx::SQLEngine::Criteria::Greater - Basic Comparison Criteria
 DBIx::SQLEngine::Criteria::Greater objects check that an
 expression is greater than a given reference value.
 
+=over 4
+
+=item sql_comparator()
+
+Returns ">".
+
+=back
+
 =head1 SEE ALSO
 
 See L<DBIx::SQLEngine::Criteria> and L<DBIx::SQLEngine::Criteria::Comparison>
